@@ -21,28 +21,28 @@
  *   Chema Celorio <chema@celorio.com>
  */
 
+#include <config.h>
+
+#include "glade.h"
+#include "glade-catalog.h"
+#include "glade-widget-adaptor.h"
 
 #include <string.h>
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
-#include "glade.h"
-#include "glade-catalog.h"
-#include "glade-widget-adaptor.h"
-#include "glade-binding.h"
-
-typedef void   (*GladeCatalogInitFunc) (void);
-
 struct _GladeCatalog
 {
-	gchar *language;	 /* Library language, NULL means language is C */
+	guint16   major_version;    /* The catalog version               */
+	guint16   minor_version;
+
+	GList *targetable_versions; /* list of suitable version targets */
+
+	gboolean libglade_supported; /* whether this catalog supports libglade */
+	gboolean builder_supported; /* whether this catalog supports gtkbuilder */
+
 	gchar *library;          /* Library name for backend support  */
 
 	gchar *name;             /* Symbolic catalog name             */
@@ -70,12 +70,14 @@ struct _GladeCatalog
 	
 	gchar *init_function_name;/* Catalog's init function name */
 	GladeCatalogInitFunc init_function;
+
+	GladeProjectConvertFunc project_convert_function; /* pointer to module's project converter */
 };
 
 struct _GladeWidgetGroup
 {
-	gchar *name;             /* Group name                        */
-	gchar *title;            /* Group name in the palette             */
+	gchar *name;             /* Group name */
+	gchar *title;            /* Group name in the palette */
 
 	gboolean expanded;       /* Whether group is expanded in the palette */
 
@@ -83,16 +85,27 @@ struct _GladeWidgetGroup
 };
 
 static void            catalog_load         (GladeCatalog     *catalog);
+
 static GladeCatalog   *catalog_open         (const gchar      *filename);
+
 static GList          *catalog_sort         (GList            *catalogs);
+
 static gboolean        catalog_load_classes (GladeCatalog     *catalog,
+
 					     GladeXmlNode     *widgets_node);
+					     
 static gboolean        catalog_load_group   (GladeCatalog     *catalog,
+
 					     GladeXmlNode     *group_node);
 
-static void            widget_group_free    (GladeWidgetGroup *group);
+static void            widget_group_destroy (GladeWidgetGroup *group);
 
-/* List of catalog names successfully loaded.
+static void            catalog_destroy      (GladeCatalog *catalog);
+
+static void            module_close         (GModule *module);
+
+
+/* List of catalogs successfully loaded.
  */
 static GList *loaded_catalogs = NULL;
 
@@ -110,13 +123,40 @@ catalog_get_function (GladeCatalog *catalog,
 	return FALSE;
 }
 
+static GladeCatalog *
+catalog_allocate (void)
+{
+	GladeCatalog *catalog;
+	
+	catalog = g_slice_new0 (GladeCatalog);
+	
+	catalog->library = NULL;
+	catalog->name = NULL;
+	catalog->dep_catalog = NULL;      
+	catalog->domain = NULL;	
+	catalog->book = NULL;
+	catalog->icon_prefix = NULL;
+	catalog->init_function_name = NULL;
+	catalog->module = NULL;
+
+	catalog->context = NULL;
+	catalog->adaptors = NULL;
+	catalog->widget_groups = NULL;
+
+	catalog->libglade_supported = FALSE;
+	catalog->builder_supported = TRUE;
+	return catalog;
+}
+
 static GladeCatalog *
 catalog_open (const gchar *filename)
 {
+	GladeTargetableVersion *version;
 	GladeCatalog    *catalog;
 	GladeXmlContext *context;
 	GladeXmlDoc     *doc;
 	GladeXmlNode    *root;
+	gchar           *str;
 
 	/* get the context & root node of the catalog file */
 	context = glade_xml_context_new_from_path (filename,
@@ -139,56 +179,71 @@ catalog_open (const gchar *filename)
 		return NULL;
 	}
 
-	catalog = g_new0 (GladeCatalog, 1);
+	catalog = catalog_allocate ();
 	catalog->context = context;
 	catalog->name    = glade_xml_get_property_string (root, GLADE_TAG_NAME);
 
 	if (!catalog->name) 
 	{
 		g_warning ("Couldn't find required property 'name' in catalog root node");
-		g_free (catalog);
-		glade_xml_context_free (context);
+		catalog_destroy (catalog);
 		return NULL;
 	}
-	
-	catalog->language =
-		glade_xml_get_property_string (root, GLADE_TAG_LANGUAGE);
-	
-	if (catalog->language && (glade_binding_get (catalog->language)) == NULL)
-	{
-		g_warning ("%s language is not supported. "
-			   "Make sure the corresponding GladeBinding module is available.",
-			   catalog->language);
-		g_free (catalog->name);
-		g_free (catalog->language);
-		g_free (catalog);
-		glade_xml_context_free (context);
-		return NULL;
-	}
-	
-	loaded_catalogs = g_list_prepend (loaded_catalogs, g_strdup (catalog->name));
-	
-	catalog->library =
-		glade_xml_get_property_string (root, GLADE_TAG_LIBRARY);
-	catalog->dep_catalog =
-		glade_xml_get_property_string (root, GLADE_TAG_DEPENDS);
-	catalog->domain =
-		glade_xml_get_property_string (root, GLADE_TAG_DOMAIN);
-	catalog->book =
-		glade_xml_get_property_string (root, GLADE_TAG_BOOK);
-	catalog->icon_prefix =
-		glade_xml_get_property_string (root, GLADE_TAG_ICON_PREFIX);
-	catalog->init_function_name =
-		glade_xml_get_value_string (root, GLADE_TAG_INIT_FUNCTION);
-	
 
+
+	glade_xml_get_property_version (root, GLADE_TAG_VERSION, 
+					&catalog->major_version,
+					&catalog->minor_version);
+
+	/* Make one default suitable target */
+	version = g_new (GladeTargetableVersion, 1);
+	version->major = catalog->major_version;
+	version->minor = catalog->minor_version;
+
+	catalog->targetable_versions = 
+		glade_xml_get_property_targetable_versions
+		(root, GLADE_TAG_TARGETABLE);
+
+	catalog->targetable_versions = g_list_prepend (catalog->targetable_versions, version);
+
+	catalog->library      = glade_xml_get_property_string (root, GLADE_TAG_LIBRARY);
+	catalog->dep_catalog  = glade_xml_get_property_string (root, GLADE_TAG_DEPENDS);
+	catalog->domain       = glade_xml_get_property_string (root, GLADE_TAG_DOMAIN);
+	catalog->book         = glade_xml_get_property_string (root, GLADE_TAG_BOOK);
+	catalog->icon_prefix  = glade_xml_get_property_string (root, GLADE_TAG_ICON_PREFIX);
+	catalog->init_function_name = glade_xml_get_value_string (root, GLADE_TAG_INIT_FUNCTION);
+
+	if (!catalog->domain)
+		catalog->domain = g_strdup (catalog->library);
+
+	if ((str = glade_xml_get_property_string (root, GLADE_TAG_SUPPORTS)) != NULL)
+	{
+		gchar **split = g_strsplit (str, ",", 0);
+		gint i;
+
+		catalog->builder_supported = FALSE;
+		
+		for (i = 0; split[i]; i++)
+		{
+			if (!strcmp (split[i], GLADE_TAG_LIBGLADE))
+				catalog->libglade_supported = TRUE;
+			else if (!strcmp (split[i], GLADE_TAG_GTKBUILDER))
+				catalog->builder_supported = TRUE;
+		}
+	}
+	
 	/* catalog->icon_prefix defaults to catalog->name */
 	if (!catalog->icon_prefix)
 		catalog->icon_prefix = g_strdup (catalog->name);
 
-	if (catalog->init_function_name && catalog->language == NULL)
+	if (catalog->init_function_name)
 		catalog_get_function (catalog, catalog->init_function_name,
 				      (gpointer) &catalog->init_function);
+	
+	if ((str = glade_xml_get_value_string (root, GLADE_TAG_PROJECT_CONVERT_FUNCTION)) != NULL)
+	{
+		catalog_get_function (catalog, str, (gpointer) &catalog->project_convert_function);
+	}
 
 	return catalog;
 }
@@ -255,7 +310,7 @@ catalog_sort (GList *catalogs)
 				(catalogs, catalog->dep_catalog,
 				 (GCompareFunc)catalog_find_by_name);
 
-			if ((cat = node->data) == NULL)
+			if (!node || (cat = node->data) == NULL)
 			{
 				g_critical ("Catalog %s depends on catalog %s, not found",
 					    catalog->name, catalog->dep_catalog);
@@ -289,30 +344,24 @@ catalog_load_library (GladeCatalog *catalog)
 	GModule *module;
 
 	if (modules == NULL)
-		modules = g_hash_table_new (g_str_hash, g_str_equal);
+		modules = g_hash_table_new_full (g_str_hash,
+					         g_str_equal,
+					         (GDestroyNotify) g_free,
+					         (GDestroyNotify) module_close);
 		
-	if (catalog->library == NULL) return NULL;
-
-	if (catalog->language)
-	{
-		GladeBinding *binding = glade_binding_get (catalog->language);
-		if (binding)
-			glade_binding_library_load (binding, catalog->library);
+	if (catalog->library == NULL)
 		return NULL;
-	}
+
+	if ((module = g_hash_table_lookup (modules, catalog->library)))
+		return module;	
+	
+	if ((module = glade_util_load_library (catalog->library)))
+		g_hash_table_insert (modules, g_strdup (catalog->library), module);
 	else
-	{
-		if ((module = g_hash_table_lookup (modules, catalog->library)))
-			return module;	
+		g_warning ("Failed to load external library '%s'",
+			   catalog->library);
 		
-		if ((module = glade_util_load_library (catalog->library)))
-			g_hash_table_insert (modules, g_strdup (catalog->library), module);
-		else
-			g_warning ("Failed to load external library '%s'",
-				   catalog->library);
-		
-		return module;
-	}
+	return module;
 }
 
 static gboolean
@@ -333,12 +382,7 @@ catalog_load_classes (GladeCatalog *catalog, GladeXmlNode *widgets_node)
 	
 		domain = catalog->domain ? catalog->domain : catalog->library;
 		
-		adaptor = glade_widget_adaptor_from_catalog (node,
-							     catalog->name,
-							     catalog->icon_prefix,
-							     module,
-			 				     domain, 
-			 				     catalog->book);
+		adaptor = glade_widget_adaptor_from_catalog (catalog, node, module);
 
 		catalog->adaptors = g_list_prepend (catalog->adaptors, adaptor);
 	}
@@ -351,8 +395,9 @@ catalog_load_group (GladeCatalog *catalog, GladeXmlNode *group_node)
 {
 	GladeWidgetGroup *group;
 	GladeXmlNode     *node;
+        char *title, *translated_title;
 
-	group = g_new0 (GladeWidgetGroup, 1);
+	group = g_slice_new0 (GladeWidgetGroup);
 	
 	group->name = glade_xml_get_property_string (group_node, 
 						     GLADE_TAG_NAME);
@@ -360,18 +405,16 @@ catalog_load_group (GladeCatalog *catalog, GladeXmlNode *group_node)
 	if (!group->name) 
 	{ 
 		g_warning ("Required property 'name' not found in group node");
-	
-		widget_group_free (group);
+		widget_group_destroy (group);
 		return FALSE;
 	}
 	
-	group->title = glade_xml_get_property_string (group_node,
-						      GLADE_TAG_TITLE);
-	if (!group->title) 
+	title = glade_xml_get_property_string (group_node,
+					       GLADE_TAG_TITLE);
+	if (!title)
 	{ 
 		g_warning ("Required property 'title' not found in group node");
-
-		widget_group_free (group);
+		widget_group_destroy (group);
 		return FALSE;	
 	}
 
@@ -379,9 +422,17 @@ catalog_load_group (GladeCatalog *catalog, GladeXmlNode *group_node)
 	group->expanded = TRUE;
 
 	/* Translate it */
-	group->title = dgettext (catalog->domain ? 
-				 catalog->domain : catalog->library, 
-				 group->title);
+	translated_title = dgettext (catalog->domain, 
+				     title);
+        if (translated_title != title)
+        {
+                group->title = g_strdup (translated_title);
+                g_free (title);
+        }
+        else
+        {
+                group->title = title;
+        }
 
 	group->adaptors = NULL;
 
@@ -426,73 +477,89 @@ catalog_load_group (GladeCatalog *catalog, GladeXmlNode *group_node)
 
 	group->adaptors = g_list_reverse (group->adaptors);
 
-	catalog->widget_groups = g_list_prepend (catalog->widget_groups,
-						 group);
+	catalog->widget_groups = g_list_prepend (catalog->widget_groups, group);
 
 	return TRUE;
 }
 
-static void
-widget_group_free (GladeWidgetGroup *group)
-{
-	g_return_if_fail (group != NULL);
-	
-	g_free (group->name);
-	g_free (group->title);
-
-	/* The actual widget classes will be free elsewhere */
-	g_list_free (group->adaptors);
-}
-	
-GList *
-glade_catalog_load_all (void)
+static GList *
+catalogs_from_path (GList *catalogs, const gchar *path)
 {
+	GladeCatalog *catalog;
 	GDir         *dir;
 	GError       *error = NULL;
 	const gchar  *filename;
-	GList        *catalogs, *l;
-	GladeCatalog *catalog;
-	
-	/* Read all files in catalog dir */
-	dir = g_dir_open (glade_app_get_catalogs_dir (), 0, &error);
-	if (!dir) 
+
+	if ((dir = g_dir_open (path, 0, &error)) != NULL)
 	{
-		g_warning ("Failed to open catalog directory: %s",
-			   error->message);
-		return NULL;
+		while ((filename = g_dir_read_name (dir)))
+		{
+			gchar *catalog_filename;
+			
+			if (!g_str_has_suffix (filename, ".xml")) 
+				continue;
+
+			catalog_filename = g_build_filename (path, filename, NULL);
+			catalog = catalog_open (catalog_filename);
+			g_free (catalog_filename);
+
+			if (catalog)
+			{
+				/* Verify that we are not loading the same catalog twice !
+				 */
+				if (!g_list_find_custom (catalogs, catalog->name,
+							 (GCompareFunc)catalog_find_by_name))
+					catalogs = g_list_prepend (catalogs, catalog);
+				else
+					catalog_destroy (catalog);
+			}
+			else
+				g_warning ("Unable to open the catalog file %s.\n", filename);
+		}
+	}
+	else
+		g_warning ("Failed to open catalog directory '%s': %s", path, error->message);
+	
+
+	return catalogs;
+}
+
+const GList *
+glade_catalog_load_all (void)
+{
+	GList         *catalogs = NULL, *l;
+	GladeCatalog  *catalog;
+	const gchar   *search_path;
+	gchar        **split;
+	gint           i;
+	
+	/* First load catalogs from user specified directories ... */
+	if ((search_path = g_getenv (GLADE_ENV_CATALOG_PATH)) != NULL)
+	{
+		if ((split = g_strsplit (search_path, ":", 0)) != NULL)
+		{
+			for (i = 0; split[i] != NULL; i++)
+				catalogs = catalogs_from_path (catalogs, split[i]);
+
+			g_strfreev (split);
+		}
 	}
 
+	/* ... Then load catalogs from standard install directory */
+	catalogs = catalogs_from_path (catalogs, glade_app_get_catalogs_dir ());
+	
 	/* Catalogs need dependancies, most catalogs depend on
 	 * the gtk+ catalog, but some custom toolkits may depend
 	 * on the gnome catalog for instance.
 	 */
-	catalogs = NULL;
-	while ((filename = g_dir_read_name (dir)))
-	{
-		gchar *catalog_filename;
-
-		if (!g_str_has_suffix (filename, ".xml")) 
-			continue;
-
-		catalog_filename = g_build_filename (glade_app_get_catalogs_dir (),
-						     filename, NULL);
-		catalog = catalog_open (catalog_filename);
-		g_free (catalog_filename);
-
-		if (catalog) 
-			catalogs = g_list_prepend (catalogs, catalog);
-		else
-			g_warning ("Unable to open the catalog file %s.\n", 
-				   filename);
-	}
-
-	/* After sorting, execute init function and then load */
 	catalogs = catalog_sort (catalogs);
 	
+	/* After sorting, execute init function and then load */
 	for (l = catalogs; l; l = l->next)
 	{
 		catalog = l->data;
-		if (catalog->init_function) catalog->init_function ();
+		if (catalog->init_function)
+			catalog->init_function (catalog->name);
 	}
 	
 	for (l = catalogs; l; l = l->next)
@@ -501,22 +568,89 @@ glade_catalog_load_all (void)
 		catalog_load (catalog);
 	}
 	
-	g_dir_close (dir);
-	return catalogs;
+	loaded_catalogs = catalogs;
+	
+	return loaded_catalogs;
 }
 
-const gchar *
+G_CONST_RETURN gchar *
 glade_catalog_get_name (GladeCatalog *catalog)
 {
-	g_return_val_if_fail (catalog != NULL, NULL);
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
 
 	return catalog->name;
 }
 
+G_CONST_RETURN gchar *
+glade_catalog_get_book (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
+
+	return catalog->book;
+}
+
+G_CONST_RETURN gchar *
+glade_catalog_get_domain (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
+
+	return catalog->domain;
+}
+
+G_CONST_RETURN gchar *
+glade_catalog_get_icon_prefix (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
+
+	return catalog->icon_prefix;
+}
+
+gboolean
+glade_catalog_supports_libglade (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), FALSE);
+
+	return catalog->libglade_supported;
+}
+
+gboolean
+glade_catalog_supports_gtkbuilder (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), FALSE);
+
+	return catalog->builder_supported;
+}
+
+
+guint16
+glade_catalog_get_major_version (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), 0);
+
+	return catalog->major_version;
+}
+
+guint16
+glade_catalog_get_minor_version (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), 0);
+
+	return catalog->minor_version;
+}
+
+
+GList *
+glade_catalog_get_targets (GladeCatalog *catalog)
+{
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
+
+	return catalog->targetable_versions;
+}
+
 GList *
 glade_catalog_get_widget_groups (GladeCatalog *catalog)
 {
-	g_return_val_if_fail (catalog != NULL, NULL);
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
 
 	return catalog->widget_groups;	
 }
@@ -524,39 +658,87 @@ glade_catalog_get_widget_groups (GladeCatalog *catalog)
 GList *
 glade_catalog_get_adaptors (GladeCatalog *catalog)
 {
-	g_return_val_if_fail (catalog != NULL, NULL);
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), NULL);
 
 	return catalog->adaptors;	
 }
 
-void
-glade_catalog_free (GladeCatalog *catalog)
+gboolean
+glade_catalog_is_loaded (const gchar *name)
 {
-	GList *list;
+	GList *l;
+	
+	g_return_val_if_fail (name != NULL, FALSE);
+	g_assert (loaded_catalogs != NULL);
+	
+	for (l = loaded_catalogs; l; l = l->next)
+	{
+		GladeCatalog *catalog = GLADE_CATALOG (l->data);
+		if (strcmp (catalog->name, name) == 0)
+			return TRUE;
+	}
+	
+	return FALSE;
+}
 
-	if (catalog == NULL)
-		return;
+static void
+catalog_destroy (GladeCatalog *catalog)
+{
+	g_return_if_fail (GLADE_IS_CATALOG (catalog));
 
 	g_free (catalog->name);
-	if (catalog->book)
-		g_free (catalog->book);
-		
-	if (catalog->icon_prefix)
-		g_free (catalog->icon_prefix);
-	
-	for (list = catalog->adaptors; list; list = list->next)
-		g_object_unref (list->data);
-	
-	g_list_free (catalog->adaptors);
+	g_free (catalog->library);	
+	g_free (catalog->dep_catalog);      
+	g_free (catalog->domain);           	
+	g_free (catalog->book);
+	g_free (catalog->icon_prefix);
+	g_free (catalog->init_function_name);
 
-	for (list = catalog->widget_groups; list; list = list->next) 
-		widget_group_free (GLADE_WIDGET_GROUP (list->data));
-				   
-	g_list_free (catalog->widget_groups);
-				   
-	
-	g_free (catalog);
+	if (catalog->adaptors)
+	{
+		/* TODO: free adaptors */
+		g_list_free (catalog->adaptors);
+	}
+
+	if (catalog->widget_groups)
+	{
+		g_list_foreach (catalog->widget_groups, (GFunc) widget_group_destroy, NULL);
+		g_list_free (catalog->widget_groups);
+	}
+
+	if (catalog->context)
+		glade_xml_context_free (catalog->context);
+
+	g_slice_free (GladeCatalog, catalog);
 }
+
+static void 
+module_close (GModule *module)
+{
+	g_module_close (module);
+}
+
+void
+glade_catalog_destroy_all (void)
+{	
+	/* close catalogs */
+	if (loaded_catalogs)
+	{
+		GList *l;
+		for (l = loaded_catalogs; l; l = l->next)
+			catalog_destroy (GLADE_CATALOG (l->data));
+		g_list_free (loaded_catalogs);
+		loaded_catalogs = NULL;
+	}
+	
+	/* close plugin modules */
+	if (modules)
+	{
+		g_hash_table_destroy (modules);
+		modules = NULL;
+	}
+}
+
 const gchar *
 glade_widget_group_get_name (GladeWidgetGroup *group)
 {
@@ -581,7 +763,7 @@ glade_widget_group_get_expanded (GladeWidgetGroup *group)
 	return group->expanded;
 }
 
-GList *
+const GList *
 glade_widget_group_get_adaptors (GladeWidgetGroup *group)
 {
 	g_return_val_if_fail (group != NULL, NULL);
@@ -589,37 +771,41 @@ glade_widget_group_get_adaptors (GladeWidgetGroup *group)
 	return group->adaptors;
 }
 
-gboolean
-glade_catalog_is_loaded (const gchar *name)
+static void
+widget_group_destroy (GladeWidgetGroup *group)
 {
-	GList *l;
-	g_return_val_if_fail (name != NULL, FALSE);
-	for (l = loaded_catalogs; l; l = l->next)
-		if (!strcmp (name, (gchar *)l->data))
-			return TRUE;
-	return FALSE;
-}
+	g_return_if_fail (GLADE_IS_WIDGET_GROUP (group));
+	
+	g_free (group->name);
+	g_free (group->title);
+	g_list_free (group->adaptors);
 
-
-static void 
-catalog_module_close (gpointer key, gpointer value, gpointer user_data)
-{
-	g_module_close (value);
-	g_free (key);
+	g_slice_free (GladeWidgetGroup, group);
 }
+	
+
 
 /**
- * glade_catalog_modules_close:
+ * glade_catalog_convert_project:
+ * @catalog: A #GladeCatalog
+ * @project: The #GladeProject to convert
+ * @new_format: The format to convert @project to
  *
- * Close every opened module.
+ * Do any data changes needed to the project for the new
+ * format in an undoable way.
  *
+ * Returns: FALSE if any errors occurred during the conversion.
  */
-void
-glade_catalog_modules_close ()
+gboolean
+glade_catalog_convert_project (GladeCatalog     *catalog,
+			       GladeProject     *project,
+			       GladeProjectFormat  new_format)
 {
-	if (modules == NULL) return;
-		
-	g_hash_table_foreach (modules, catalog_module_close, NULL);
-	g_hash_table_destroy (modules);
-	modules = NULL;
+	g_return_val_if_fail (GLADE_IS_CATALOG (catalog), FALSE);
+	g_return_val_if_fail (GLADE_IS_PROJECT (project), FALSE);
+
+	if (catalog->project_convert_function)
+		return catalog->project_convert_function (project, new_format);
+
+	return TRUE;
 }
