@@ -334,7 +334,6 @@ glade_property_get_value_impl (GladeProperty *property, GValue *value)
 static void
 glade_property_sync_impl (GladeProperty *property)
 {
-
 	/* Heh, here are the many reasons not to
 	 * sync a property ;-)
 	 */
@@ -351,6 +350,14 @@ glade_property_sync_impl (GladeProperty *property)
 	    property->widget == NULL)
 		return;
 
+	/* Only the properties from widget->properties should affect the runtime widget.
+	 * (other properties may be used for convenience in the plugin).
+	 */
+	if ((property->klass->packing && 
+	     property != glade_widget_get_pack_property (property->widget, property->klass->id)) ||
+	    property != glade_widget_get_property (property->widget, property->klass->id))
+		return;
+
 	property->syncing++;
 
 	/* In the case of construct_only, the widget instance must be rebuilt
@@ -844,6 +851,8 @@ glade_property_equals (GladeProperty *property, ...)
  * @value: a #GValue
  *
  * Sets the property's value
+ *
+ * Returns: Whether the property was successfully set.
  */
 gboolean
 glade_property_set_value (GladeProperty *property, const GValue *value)
@@ -1012,7 +1021,7 @@ glade_property_read (GladeProperty      *property,
 	GladeProjectFormat fmt;
 	GValue       *gvalue = NULL;
 	gchar        /* *id, *name, */ *value;
-	gint translatable, has_context;
+	gint translatable = FALSE, has_context = FALSE;
 	gchar *comment = NULL, *context = NULL;
 
 	g_return_if_fail (GLADE_IS_PROPERTY (property));
